==> abills-0.32.tgz: abills/language/ukraine.pl <==
$_LOG="";
$_RECV="";
$_TARIF_PLANS=" ";
$_ACCOUNT="";
$_NOT_LOGINED="  ";
$_TRAFIC_TARIFS=" ";
$_SDETAIL=" ";
$_LIMIT="˳";
$_AUTH="";
$_CREDITORS="";
$_EXIST="  ";
$_INPAYMENTS="";
$_DEFAULT=" ";
$_PERIOD="";
$_MAILBOXES=" ";
$_CARD_SERVICE="  ";
@PERIODS=('', '', '', '̳', ' ', '³ ');;;;;;;;;;
$_AVG=" ";
$_NOW="";
$_LAST_LOGIN=" ";
$_USER="";
$_MESSAGE="";
$_BEGIN="";
$_USER_INFO="  ";
$_DAY="";
$_ALLOW_ALL="  ";
$_NOT_ACTIVE=" ";
$_USERS="";
$_REFRESH="";
$_TRANSPORT=" ";
@WEEKDAYS=('', '', '³', '', '', '', '', '');;;;;;;;;;
$_NUM="";
$_MESSAGES="";
$_DURATION="";
$_CONFIRM="ϳ";
$_STATUS=" ";
$_MONTH="̳";
$_SA_ONLY=" ҳ ";
$_ENTER="";
$_FILTERS="Գ";
$_ABON=". ";
$_DOMAINS=" ";
$_ERROR=" ";
$_YEAR="г";
$_SQL_BACKUP=" ";
$_HANGUPED="³";
$_WEEK="";
$_USER_NOT_EXIST="   ";
$_OPTIONS="";
$_MIN_SESSION_COST="̳  ";
$_USER_EXIST="   ";
$_RESET="";
$_WRONG_PASSWD="     ";
$_RECORDS="";
$_SYSTEM=" ";
$_AGE=" ";
$_REVISION="";
$_GROUP="";
$_DATE="";
$_GO=" ";
$_ANTISPAM="";
$_HOLIDAYS=" ";
$_POSTPAID=" ";
$_HOURS="";
$_TO_USER="";
$_DELETED="";
$_DUNES="   Windows (DUNES)";
$_MONETARY_UNIT=" ";
$_BANK_INFO="";
$_FIO=" ";
$_MAKE_BACKAUP=" ";
$_PAYMENTS="";
$_BRUTE_ATACK=" ";
$_MAIL_BOX=" ";
$_CHANGING=" ";
$_FILE="";
$_CHANGED=" ";
@MONTHES=('ѳ', '', '', '', '', '', '', '', '', '', '', '');;;;;;;;;;
$_HOSTS="";
$_TRAFFIC="";
$_END="ʳ";
$_SIZE="";
$_SYMBOLS="";
$_OCTETS_DIRECTION=" ";
$_VARIANT=" ";
$_PAYMENT_NOTEXIST="  ";
$_MANAGE=" ";
$_TEST="";
$_UPLIMIT="";
$_VARIANTS=" ";
$_DELETE_USER="   ";
$CHARSET=" windows-1251";
$_REMAIN="";
$_GETED="";
$_COMMENTS="";
$_BACK_MONEY="   ";
$_LAST=" ";
$_ERROR_LOG=" ";
$_ACCOUNT_EXIST="  ";
$_HOUR_TARIF=" ";
$_ALIASES=" Aliases";
$_SENT="³";
$_EXPIRE="";
$_REDUCTION="";
$_SENDED="³";
$_PREFIX=" ";
$_TYPE="";
$ERR_SELECT_VARIANT=" ";
$_ORDER="";
$ERR_SHORT_PASSWD=" .    6 ";
$_PROFILE="";
$_ENABLE="";
$ERR_WRONG_CONFIRM="  ";
$_MONITORING="";
$_CREATE="";
$_WRONG_EMAIL=" E-mail ";
$_GENERED_PARRWORD="  ";
$_INFO="";
$_PAY_CARDS="  ";
$_PREPAID="";
$_DEL="";
$_GEN_PASSWD=" ";
$_NO_RECORD=" ";
$_INTERVALS="";
$_SELECT_USER=" ";
$_FOLDER="";
$_VALUE="";
$_PAYMENT_ADDED="    ";
$_DAY_FEE=" .";
$_ACCESS="";
$_LOGOUT="";
$_MESSAGES_DESCRIBE="         .";
$_COR_BANK_ACCOUNT=". ";
$_ALLOW=" ";
$_MONEY="";
$_STATS="";
$_NASS=" ";
$_BYTE_TARIF=" ";
$_PERMISSION="";
$_SEND="³";
$_TIME_LIMIT="˳ ";
$_NAME="";
$_YES="";
$_MONTH_FEE="̳ .";
$ERR_NAME_TOOLONG="     ";
$_SUM="";
$_TIME=" ";
$_FUNCTIONS_LIST="";
$_MIN="̳";
$_COMPANY="";
$_NAS_STATISTIC="  ";
$_SET="";
$_ADD_USER=" ";
$_LENGTH="";
$_SHEDULE="";
$_DESCRIBE="";
$_COUNT="ʳ";
$_NOT_EXIST=" ";
$_DETAIL="";
$_FROM="";
$_BALANCE="";
$_PRE=" ";
$_TRAF_LIMIT="˳ ";
$_PAYMENT_DELETED=" ";
$_MODULES=" ";
$_ACTIVATE="";
$_ACCOUNTS=" ";
$_ROUTES="";
$_BILLING=" ";
$_BANK_NAME=" ";
$_ADD="";
$_DELETED_USER=" ";
$_REPLY=" ³";
$_ROWS="";
$_DAY_DURATION=" ";
$_PARAMS="";
$_EXCHANGE_RATE="  ";
$_ADDED="";
$_BACK_PAY="";
$_REGISTRATION="";
$_PAYMENT_TYPE=" ";
$_MAX_SESSION_DURATION=".  ";
$_TEMPLATES="";
$_ADDRESS="";
$_CONFIRM_PASSWD="ϳ ";
$_CHANGE="";
$_PER_MONTH=" ";
$_NO="ͳ";
$_SERVICES="";
$_PHONE="";
$ERR_ENTER_USER_NAME="  ";
$_DOCS="";
$_PRINT="";
$_ANTIVIRUS="";
$_SERIAL="--";
$_NAS=" ";
$_CREDIT="";
$_FEES=" ";
$_CUSTOMERS="볺";
$_ALLOW_NAS="   ";
$_NAS_CONFIG="  ";
$_CHANGE_PASSWD=" ";
$_SUBJECT="";
$_DOMAIN=" ";
$_DICTIONARY="";
$_GROUPS="";
$_SHOW="";
$_DISABLE="";
$_LOGINS="";
$_ADDRESS_FLAT="";
$_MAX="";
$_PAYMENT_METHOD=" ";
$_ADMIN="";
$_TARIF_PLAN=" ";
$_BILL=" ";
$_SESSION_ID=" ";
$_PORT="";
$ERR_WRONG_NAME=" \";
$_SESSIONS="";
$_ADMINS="";
$_SHOW_ALL="  ";
$_TAKE="";
$_SPEED=" ";
$_REPORTS=" ";
$_TOTAL="";
$_PARAM="";
$_CUSTOMER="볺";
$_PASSWD="";
$_OTHER="";
$_CLOSED="";
$_TAX_NUMBER="";
$_TO="";
$_NETWORKS="ѳ";
$_LIST="";
$_LAST_PAYMENT=" ";
$_START="";
$_TEXT="";
$_USED="";
$_OPERATOR="";
$_STATE=" ";
$_ALL="";
$_NO_SUM=" ";
$_SEARCH="";
$_HANGUP="³";
$_CREDIT_TRESSHOLD=" ";
$_DAYS="";
$_SIMULTANEOUSLY="";
$_CONTRACT_ID=" ";
$_BANK_BIC="";
$_ADDRESS_BUILD="ĳ";
$_ZAPED="";
$_ADDRESS_STREET="";
$_RESETED="";
$_ACTIV="";
$_GET="";
$_ICARDS="  ";
$_SHORT_NAME=" ";
$_LOGIN="";
$_WELCOME=" ";
$_CREATED="";
$_RESULT="";
$_LANGUAGE="";
$_SEND_MAIL="³ e-mail";
$_RELAYS=" Relay,";
$_DEPOSIT="";
$_BILLS=" ";

==> abills-0.33.tgz: abills/language/ukraine.pl <==
$_LOG="";
$_RECV="";
$_TARIF_PLANS=" ";
$_ACCOUNT="";
$_NOT_LOGINED="  ";
$_TRAFIC_TARIFS=" ";
$_SDETAIL=" ";
$_LIMIT="˳";
$_AUTH="";
@WEEKDAYS=('', '', '³', '', '', '', '', '');;;
$_CREDITORS="";
$_EXIST="  ";
$_INPAYMENTS="";
$_DEFAULT=" ";
$_PERIOD="";
$_MAILBOXES=" ";
$_CARD_SERVICE="  ";
$_AVG=" ";
$_NOW="";
$_LAST_LOGIN=" ";
$_USER="";
$_MESSAGE="";
$_BEGIN="";
$_USER_INFO="  ";
$_DAY="";
$_ALLOW_ALL=" ";
$_NOT_ACTIVE=" ";
$_USERS="";
$_REFRESH="";
$_TRANSPORT="";
$_NUM="";
$_MESSAGES="";
$_DURATION="";
$_CONFIRM="ϳ";
$_STATUS="";
$_MONTH="̳";
$_SA_ONLY=" ҳ ";
$_ENTER="";
$_FILTERS="Գ";
$_ABON=". ";
$_DOMAINS=" ";
$_ERROR=" ";
$_YEAR="г";
$_SQL_BACKUP=" ";
$_HANGUPED="³";
$_WEEK="";
$_USER_NOT_EXIST="   ";
$_OPTIONS="";
$_MIN_SESSION_COST="̳  ";
$_USER_EXIST="   ";
$_RESET="";
$_WRONG_PASSWD="     ";
$_RECORDS="";
$_SYSTEM="c";
$_AGE=" ";
$_REVISION="";
$_GROUP="";
$_DATE="";
$_GO=" ";
$_ANTISPAM="";
$_HOLIDAYS=" ";
$_POSTPAID=" ";
$_HOURS="";
$_TO_USER="";
$_DELETED="";
$_DUNES="   Windows (DUNES)";
$_MONETARY_UNIT=" ";
$_BANK_INFO="";
$_FIO=" ";
$_MAKE_BACKAUP=" ";
$_PAYMENTS="";
$_BRUTE_ATACK=" ";
$_MAIL_BOX=" ";
$_CHANGING=" ";
$_FILE="";
$_CHANGED=" ";
$_HOSTS="";
$_TRAFFIC="";
$_END="ʳ";
$_SIZE="";
$_SYMBOLS="";
$_OCTETS_DIRECTION=" ";
$_VARIANT=" ";
$_PAYMENT_NOTEXIST="  ";
$_MANAGE=" ";
$_TEST="";
$_UPLIMIT="";
$_VARIANTS=" ";
$_DELETE_USER="   ";
$CHARSET=" windows-1251";
$_REMAIN="";
$_GETED="";
$_COMMENTS="";
$_BACK_MONEY="   ";
$_LAST=" ";
$_ERROR_LOG=" ";
$_ACCOUNT_EXIST="  ";
$_HOUR_TARIF=" ";
$_ALIASES="Aliases";
$_SENT="³";
$_EXPIRE="";
$_REDUCTION="";
$_SENDED="³";
$_PREFIX=" ";
$_TYPE="";
$ERR_SELECT_VARIANT=" ";
$_ORDER="";
$ERR_SHORT_PASSWD=" .    6 ";
$_PROFILE="";
$_ENABLE="";
$ERR_WRONG_CONFIRM="  ";
$_MONITORING="";
$_CREATE="";
$_WRONG_EMAIL=" E-mail ";
$_GENERED_PARRWORD="  ";
$_INFO="";
$_PAY_CARDS="  ";
$_PREPAID="";
$_DEL="";
$_GEN_PASSWD=" ";
$_NO_RECORD=" ";
$_INTERVALS="";
$_SELECT_USER=" ";
$_FOLDER="";
$_VALUE="";
$_PAYMENT_ADDED="    ";
$_DAY_FEE=" .";
$_ACCESS="";
$_LOGOUT="";
$_MESSAGES_DESCRIBE="         .";
$_COR_BANK_ACCOUNT=". ";
$_ALLOW="";
$_MONEY="";
$_STATS="";
$_NASS=" ";
$_BYTE_TARIF=" ";
$_PERMISSION="";
$_SEND="³";
$_TIME_LIMIT="˳ ";
$_NAME="";
$_YES="";
$_MONTH_FEE="̳ .";
$ERR_NAME_TOOLONG="     ";
$_SUM="";
$_TIME=" ";
$_FUNCTIONS_LIST="";
$_MIN="̳";
$_COMPANY="";
$_NAS_STATISTIC="  ";
$_SET="";
$_ADD_USER=" ";
$_LENGTH="";
$_SHEDULE="";
$_DESCRIBE="";
$_COUNT="ʳ";
$_NOT_EXIST=" ";
$_DETAIL="";
$_FROM="";
$_BALANCE="";
@PERIODS=('', '', '', '̳', ' ', '³ ');;;;
$_PRE=" ";
$_TRAF_LIMIT="˳ ";
$_PAYMENT_DELETED=" ";
$_MODULES=" ";
$_ACTIVATE="";
$_ACCOUNTS="";
$_ROUTES="";
$_BILLING=" ";
$_BANK_NAME=" ";
$_ADD="";
$_DELETED_USER=" ";
$_REPLY=" ³";
$_ROWS="";
$_DAY_DURATION=" ";
$_PARAMS="";
$_EXCHANGE_RATE="  ";
$_ADDED="";
$_BACK_PAY="";
$_REGISTRATION="";
$_PAYMENT_TYPE=" ";
$_MAX_SESSION_DURATION=".  ";
$_TEMPLATES="";
$_ADDRESS="";
$_CONFIRM_PASSWD="ϳ ";
$_CHANGE="";
$_PER_MONTH=" ";
$_NO="ͳ";
$_SERVICES="";
$_PHONE="";
$ERR_ENTER_USER_NAME="  ";
$_DOCS="";
$_PRINT="";
$_ANTIVIRUS="";
$_SERIAL="--";
$_NAS=" ";
$_CREDIT="";
$_FEES=" ";
$_CUSTOMERS="볺";
$_ALLOW_NAS="  ";
$_NAS_CONFIG="  ";
$_CHANGE_PASSWD=" ";
$_SUBJECT="";
$_DOMAIN=" ";
$_DICTIONARY="";
$_GROUPS="";
$_SHOW="";
$_DISABLE="";
$_LOGINS="";
$_ADDRESS_FLAT="";
$_MAX="";
$_PAYMENT_METHOD=" ";
$_ADMIN="";
$_TARIF_PLAN=" ";
$_BILL=" ";
$_SESSION_ID=" ";
$_PORT="";
$ERR_WRONG_NAME=" \";
$_SESSIONS="";
$_ADMINS="";
$_SHOW_ALL="  ";
$_TAKE="";
$_SPEED="";
$_REPORTS=" ";
$_TOTAL="";
$_PARAM="";
$_CUSTOMER="볺";
$_PASSWD="";
$_OTHER="";
$_CLOSED="";
$_TAX_NUMBER="";
$_TO="";
$_NETWORKS="ѳ";
$_LIST="";
$_LAST_PAYMENT=" ";
$_START="";
$_TEXT="";
$_USED="";
$_OPERATOR="";
$_STATE="";
$_ALL="";
$_NO_SUM=" ";
$_SEARCH="";
$_HANGUP="³";
$_CREDIT_TRESSHOLD=" ";
$_DAYS="";
$_SIMULTANEOUSLY="";
$_CONTRACT_ID=" ";
$_BANK_BIC="";
$_ADDRESS_BUILD="ĳ";
$_ZAPED="";
$_ADDRESS_STREET="";
$_RESETED="";
$_ACTIV="";
$_GET="";
$_ICARDS="  ";
@MONTHES=('ѳ', '', '', '', '', '', '', '', '', '', '', '');;;;;
$_SHORT_NAME=" ";
$_LOGIN="";
$_WELCOME=" ";
$_CREATED="";
$_RESULT="";
$_LANGUAGE="";
$_SEND_MAIL="³ e-mail";
$_RELAYS=" Relay,";
$_DEPOSIT="";
$_BILLS=" ";
